@@ -8,7 +8,6 @@ import copy
 from decimal import Decimal
 
 from lxml import etree
-from xml.dom.minidom import parseString
 
 from simple_idml.components import get_idml_xml_file_by_name
 from simple_idml.components import (Designmap, Spread, Story, BackingStory,
@@ -16,7 +15,7 @@ from simple_idml.components import (Designmap, Spread, Story, BackingStory,
 from simple_idml.decorators import use_working_copy
 from simple_idml.utils import increment_filename, prefix_content_filename, tree_to_etree_dom
 
-from simple_idml import IdPkgNS, BACKINGSTORY
+from simple_idml import BACKINGSTORY
 
 STORIES_DIRNAME = "Stories"
 
@@ -111,7 +110,7 @@ class IDMLPackage(zipfile.ZipFile):
             append_childs(source_node, structure)
             self._xml_structure = structure
         return self._xml_structure
-    
+
     def xml_structure_pretty(self):
         return etree.tostring(self.xml_structure, pretty_print=True)
 
@@ -211,15 +210,25 @@ class IDMLPackage(zipfile.ZipFile):
             self._stories = stories
         return self._stories
 
+    def stories_for_node(self, node_path):
+        return ["%s/Story_%s.xml" % (STORIES_DIRNAME, child.get("XMLContent"))
+                for child in self.xml_structure.xpath(node_path)[0].iter()
+                if child.get("XMLContent") in self.story_ids]
+
     @property
     def story_ids(self):
         """ extract  `ID' from `Stories/Story_ID.xml'. """
         if self._story_ids is None:
-            rx_story_id = re.compile(r"%s/Story_([\w]+)\.xml" % STORIES_DIRNAME)
-            story_ids = [rx_story_id.match(elt).group(1) for elt in self.stories]
-            self._story_ids = story_ids
+            self._story_ids = self._get_story_ids_for_stories(self.stories)
         return self._story_ids
 
+    def story_ids_for_node(self, node_path):
+        return self._get_story_ids_for_stories(self.stories_for_node(node_path))
+
+    def _get_story_ids_for_stories(self, stories):
+        rx_story_id = re.compile(r"%s/Story_([\w]+)\.xml" % STORIES_DIRNAME)
+        return [rx_story_id.match(elt).group(1) for elt in stories]
+
     @property
     def referenced_layers(self):
         if self._referenced_layers is None:
@@ -309,7 +318,7 @@ class IDMLPackage(zipfile.ZipFile):
                 if style_name:
                     style_node = self.style.get_style_node_by_name(style_name)
                     nested_styles.insert(0, style_node)
-                xml_structure_node = xml_structure_node.getparent() 
+                xml_structure_node = xml_structure_node.getparent()
 
             # Merge the styles starting from the top parent like in a HTML document.
             root_style_node = nested_styles.pop(0)
@@ -353,7 +362,7 @@ class IDMLPackage(zipfile.ZipFile):
             new_xml_element = XMLElement(tag=source_node.tag)
             new_xml_element.add_content(source_node.text, parent, style_range_node)
             story.add_element(element_id, new_xml_element.element)
-            
+
             xml_structure_new_node.set("Self", new_xml_element.get("Self"))
 
             # Source may also contains some children.
@@ -405,12 +414,12 @@ class IDMLPackage(zipfile.ZipFile):
         return self
 
     def export_as_tree(self):
-        """ 
-        >>> tree = {
-        ...     "tag": "Root",
-        ...     "attrs": {...},
-        ...     "content": ["foo", {subtree}, "bar", ...]
-        ... }
+        """
+        tree = {
+            "tag": "Root",
+            "attrs": {...},
+            "content": ["foo", {subtree}, "bar", ...]
+        }
         """
         def _export_content_as_tree(xml_structure_node):
             content = []
@@ -436,7 +445,7 @@ class IDMLPackage(zipfile.ZipFile):
             if len(story_content_and_xmlelement_nodes):
                 # Leaf with content.
                 if len(xml_structure_node_children) == 0:
-                    content.append("".join([c.text or "" for c in story_content_and_xmlelement_nodes])) # if not XMLElement
+                    content.append("".join([c.text or "" for c in story_content_and_xmlelement_nodes]))  # if not XMLElement
                 # Node with content.
                 else:
                     xml_structure_child_node = xml_structure_node_children.pop(0)
@@ -540,7 +549,7 @@ class IDMLPackage(zipfile.ZipFile):
             story.clear_element_content(node.get("Self"))
             story.remove_element(node.get("Self"), synchronize=True)
             # call story.remove_xml_element_page_items() for images ?
-            
+
             spread = self.get_spread_object_by_xpath(xpath)
             if spread:
                 spread.remove_page_item(element_content_id, synchronize=True)
@@ -708,7 +717,7 @@ class IDMLPackage(zipfile.ZipFile):
           </XMLElement>
 
         o The Story_udd.xml is created.
-        o The Spread page item 'udd' is updated. 
+        o The Spread page item 'udd' is updated.
         o The designmap.xml file is updated.
 
         """
@@ -727,7 +736,7 @@ class IDMLPackage(zipfile.ZipFile):
         # To keep the document valid, the solution is to create a proxy story.
         if content_ref and (content_ref not in self.story_ids):
             self.add_story_with_content(content_ref, xml_element_dest_id, xml_element_dest.tag)
-            self.xml_element_leaf_to_node(at, content_ref) 
+            self.xml_element_leaf_to_node(at, content_ref)
             xml_element_dest = self.xml_structure.xpath(at)[0]
 
         story_dest_filename = self.get_story_by_xpath(at)
@@ -741,19 +750,18 @@ class IDMLPackage(zipfile.ZipFile):
         story_dest_elt.append(story_src_elt_copy)
         story_dest.synchronize()
 
-        # Stories files are added.
+        # Add Story files.
         # `Stories' directory may not be present in the destination package.
         stories_dirname = os.path.join(self.working_copy_path, STORIES_DIRNAME)
         if not os.path.exists(stories_dirname):
             os.mkdir(stories_dirname)
-        # TODO: add only the stories required.
-        for filename in idml_package.stories:
+        for filename in idml_package.stories_for_node(only):
             story_cp = open(os.path.join(self.working_copy_path, filename), mode="w+")
             story_cp.write(idml_package.open(filename, mode="r").read())
             story_cp.close()
 
         # Update designmap.xml.
-        self.designmap.add_stories(idml_package.story_ids)
+        self.designmap.add_stories(idml_package.story_ids_for_node(only))
         self.designmap.synchronize()
         # BackingStory.xml ??
         self.init_lazy_references()
@@ -788,12 +796,12 @@ class IDMLPackage(zipfile.ZipFile):
 
     @use_working_copy
     def add_story_with_content(self, story_id, xml_element_id, xml_element_tag):
-        story = Story.create(self, story_id, xml_element_id, xml_element_tag, self.working_copy_path)
+        Story.create(self, story_id, xml_element_id, xml_element_tag, self.working_copy_path)
         self.designmap.add_stories([story_id])
         self.designmap.synchronize()
         self.init_lazy_references()
         return self
-    
+
     @use_working_copy
     def xml_element_leaf_to_node(self, xpath, xml_content_ref):
         spread = self.get_spread_object_by_xpath(xpath)
